@@ -6,10 +6,10 @@
 """
 Contains handlers for the Mito API
 """
-from ast import Call
 from queue import Queue
 from threading import Thread
 from typing import Any, Callable, Dict, List, NoReturn, Union
+from mitosheet.api.get_params import get_params
 from mitosheet.api.get_column_describe import get_column_describe
 from mitosheet.api.get_datafiles import get_datafiles
 from mitosheet.api.get_dataframe_as_csv import get_dataframe_as_csv
@@ -17,7 +17,6 @@ from mitosheet.api.get_dataframe_as_excel import get_dataframe_as_excel
 from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
 from mitosheet.api.get_path_contents import get_path_contents
 from mitosheet.api.get_path_join import get_path_join
-from mitosheet.api.get_pivot_params import get_pivot_params
 from mitosheet.api.get_search_matches import get_search_matches
 from mitosheet.api.get_unique_value_counts import get_unique_value_counts
 from mitosheet.api.get_column_summary_graph import get_column_summary_graph
@@ -126,8 +125,8 @@ def handle_api_event(
         result = get_column_summary_graph(event, steps_manager)
     elif event["type"] == "get_column_describe":
         result = get_column_describe(event, steps_manager)
-    elif event["type"] == "get_pivot_params":
-        result = get_pivot_params(event, steps_manager)
+    elif event["type"] == "get_params":
+        result = get_params(event, steps_manager)
     elif event["type"] == "get_excel_file_metadata":
         result = get_excel_file_metadata(event, steps_manager)
     elif event["type"] == "get_unique_value_counts":
