@@ -8,10 +8,10 @@ import os
 from typing import Any, Dict
 
 import pandas as pd
-from mitosheet.steps_manager import StepsManager
+from mitosheet.types import StepsManagerType
 
 
-def get_excel_file_metadata(event: Dict[str, Any], steps_manager: StepsManager) -> str:
+def get_excel_file_metadata(event: Dict[str, Any], steps_manager: StepsManagerType) -> str:
     """
     Given a 'file_name' that should be an XLSX file, 
     will get the metadata for that XLSX file. 
