@@ -82,3 +82,16 @@ def get_location() -> str:
         return 'location_unknown_notebook'
     else:
         return 'location_unknown'
+
+
+# https://stackoverflow.com/questions/43878953/how-does-one-detect-if-one-is-running-within-a-docker-container-within-python
+def _is_docker() -> bool:
+    path = '/proc/self/cgroup'
+    return (
+        os.path.exists('/.dockerenv') or
+        os.path.isfile(path) and any('docker' in line for line in open(path))
+    )
+# We cache this so we don't have to take a performance impact
+IS_DOCKER = _is_docker()
+def is_docker() -> bool:
+    return IS_DOCKER
